# [lmlib](http://lmlib.ch/2.0/html/index.html)

---
*Version: 2.0RC CFR 1 — Open-source and for Python.*

A Model-Based Signal Processing Library Working With Windowed Linear State-Space and Polynomial Signal Models.

**Website and Documentation**: **[lmlib.ch](http://lmlib.ch/2.0/html/index.html)**

Direct Links to:
* **[API](http://lmlib.ch/2.0/html/api.html)**
* **[Coding](http://lmlib.ch/2.0/html/_gallery_coding/index.html)**
* **[Examples](http://lmlib.ch/2.0/html/_gallery_examples/index.html)**
* **[Signal Catalog](http://lmlib.ch/2.0/html/catalog.html)**
* **[Install](http://lmlib.ch/2.0/html/install.html)**
* **[About Us](http://lmlib.ch/2.0/html/about.html)**
* **[Bibliography](http://lmlib.ch/2.0/html/Bibliography.html)**


---
## Install lmlib
* **pip: ```pip install lmlib ```**
* **pip (dev-mode): ```pip install -e lmlib ```**

* **conda: [see here](http://lmlib.ch/2.0/html/install.html)**
